==> TOmicsVis_1.1.8.tar.gz: TOmicsVis/NEWS.md <==
## TOmicsVis 1.1.8

**Date**: 2023-07-06

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed DESCRIPTION: Title, Description, Authors.
2. Fixed `return` and `\value`: wgcna_pipeline.Rd.
3. Fixed examples are commented out: circos_heatmap.Rd, wgcna_pipeline.Rd.
4. Fixed dir.create() to tempdir(): wgcna_pipeline.R.
5. Fixed seed to a specific number: tsne_plot.R.
6. Fixed Lengthy examples (> 5 sec): 

---

## TOmicsVis 1.1.7

**Date**: 2023-07-05

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::dendro_plot` plot function.
2. New `?TOmicsVis::gene_rank_plot` plot function.
3. New vignettes documents.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

---

## TOmicsVis 1.1.6

**Date**: 2023-07-03

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed test problems from CRAN team.
2. Update README.rmd and README.md.

---

## TOmicsVis 1.1.5

**Date**: 2023-07-02

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::heatmap_group_data` plot function.
2. New `?TOmicsVis::heatmap_group` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed import and importFrom problems.

---

## TOmicsVis 1.1.4

**Date**: 2023-07-01

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::network_data` plot function.
2. New `?TOmicsVis::network_plot` plot function.
3. New `?TOmicsVis::wgcna_gene_exp` plot function.
4. New `?TOmicsVis::wgcna_sample_group` plot function.
5. New `?TOmicsVis::wgcna_pipeline` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.1.3

**Date**: 2023-06-30

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::kegg_enrich` plot function.
2. New `?TOmicsVis::kegg_enrich_bar` plot function.
3. New `?TOmicsVis::kegg_enrich_dot` plot function.
4. New `?TOmicsVis::kegg_enrich_tree` plot function.
5. New `?TOmicsVis::kegg_enrich_net` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.1.2

**Date**: 2023-06-30

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::go_enrich_bar` plot function.
2. New `?TOmicsVis::go_enrich_dot` plot function.
3. New `?TOmicsVis::go_enrich_tree` plot function.
4. New `?TOmicsVis::go_enrich_net` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.1.1

**Date**: 2023-06-30

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::go_anno` example dataset.
2. New `?TOmicsVis::go_deg_fc` plot function.
3. New `?TOmicsVis::go_enrich` plot function.
4. New `?TOmicsVis::go_enrich_stat` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.1.0

**Date**: 2023-06-28

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::table_cross_data1` example dataset.
2. New `?TOmicsVis::table_cross_data2` plot function.
3. New `?TOmicsVis::table_cross` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.9

**Date**: 2023-06-27

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::table_merge_data` example dataset.
2. New `?TOmicsVis::table_merge` plot function.
3. New `?TOmicsVis::table_filter_data` example dataset.
4. New `?TOmicsVis::table_filter` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.8

**Date**: 2023-06-26

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::survival_data` example dataset.
2. New `?TOmicsVis::survival_plot` plot function.
3. New `?TOmicsVis::tsne_data` example dataset.
4. New `?TOmicsVis::tsne_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.7

**Date**: 2023-06-26

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::trend_data` example dataset.
2. New `?TOmicsVis::trend_plot` plot function.
3. New `?TOmicsVis::table_split_data` example dataset.
4. New `?TOmicsVis::table_split` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `_pkgdown.yml` categories and functions.

---

## TOmicsVis 1.0.6

**Date**: 2023-06-25

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::deg_data` example dataset.
2. New `?TOmicsVis::volcano_plot` plot function.
3. New `?TOmicsVis::deg_data2` example dataset.
4. New `?TOmicsVis::ma_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.5

**Date**: 2023-06-24

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::chord_data` example dataset.
2. New `?TOmicsVis::chord_plot` plot function.
3. New `?TOmicsVis::circos_heatmap_data` example dataset.
4. New `?TOmicsVis::circos_heatmap` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Set function invisible().

---

## TOmicsVis 1.0.4

**Date**: 2023-06-23

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::quantile_data` example dataset.
2. New `?TOmicsVis::quantile_plot` plot function.
3. New `?TOmicsVis::venn_data` example dataset.
4. New `?TOmicsVis::venn_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.3

**Date**: 2023-06-22

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::box_data` example datasets.
2. New `?TOmicsVis::box_plot` plot function.
3. New `?TOmicsVis::violin_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `_pkgdown.yml` theme configure.

---

## TOmicsVis 1.0.2

**Date**: 2023-06-21

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::pca_sample_gene` and `?TOmicsVis::pca_group_sample` example datasets.
2. New `?TOmicsVis::pca_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `_pkgdown.yml` configure reference `ggplot2`: [https://github.com/tidyverse/ggplot2/blob/main/README.Rmd](https://github.com/tidyverse/ggplot2/blob/main/README.Rmd).

---

## TOmicsVis 1.0.1

**Date**: 2023-06-20

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. Open source code of TOmicsVis to github: [https://github.com/benben-miao/TOmicsVis/](https://github.com/benben-miao/TOmicsVis/).
2. Build pkgdown website: [https://benben-miao.github.io/TOmicsVis/](https://benben-miao.github.io/TOmicsVis/) for TOmicsVis package.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `DESCRIPTION` import parameters
2. Fixed `_pkgdown.yml` configure file using Visual Studio Code.

---

## TOmicsVis 1.0.0

**Date**: 2023-06-20

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. Create TOmicsVis package and complete the `DESCRIPTION` file.
2. New `?TOmicsVis::gene_exp` example data and `?TOmicsVis::corr_heatmap` function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

None

==> TOmicsVis_1.2.3.tar.gz: TOmicsVis/NEWS.md <==
## TOmicsVis 1.2.3

**Date**: 2023-07-20

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Update R-4.2.2 to R-4.3.1.
2. Fixed CRAN problems by close go_enrich_tree and kegg_enrich_tree.
3. Update heatmap_cluster function.
4. Update pkgdown website: Installation, Tutorials, Courses.

---

## TOmicsVis 1.2.2

**Date**: 2023-07-18

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `?TOmicsVis::box_plot` and `?TOmicsVis::violin_plot` by changing wilcox.test to t.test.
2. Fixed `?TOmicsVis::dendro_plot` by adding supperssWarning.
3. Fixed `?TOmicsVis::tsne_plot` by changing aes to aes_string.
4. Fixed function for avoiding warning messages.
5. Fixed `?TOmicsVis::go_enrich_bar` and `?TOmicsVis::kegg_enrich_bar` Count aes.

---

## TOmicsVis 1.2.1

**Date**: 2023-07-14

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `?TOmicsVis::tsne_plot` function.
2. Change README.Rmd fig.width=10.00, fig.height=6.18.
3. Update GO and KEGG example datasets.
4. Fixed GO and KEGG enrichment results.

---

## TOmicsVis 1.2.0

**Date**: 2023-07-07

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Add e1071 to Denps in DESCRIPTION.
2. Fixed gene_cluster_trend.R, flower_plot.

---

## TOmicsVis 1.1.9

**Date**: 2023-07-07

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::gene_cluster_data` plot function.
2. New `?TOmicsVis::gene_cluster_trend` plot function.
3. New `?TOmicsVis::flower_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

---

## TOmicsVis 1.1.8

**Date**: 2023-07-06

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed DESCRIPTION: Title, Description, Authors.
2. Fixed `return` and `\value`: wgcna_pipeline.Rd.
3. Fixed examples are commented out: circos_heatmap.Rd, wgcna_pipeline.Rd.
4. Fixed dir.create() to tempdir(): wgcna_pipeline.R.
5. Fixed seed to a specific number: tsne_plot.R.
6. Fixed Lengthy examples (> 5 sec): 

---

## TOmicsVis 1.1.7

**Date**: 2023-07-05

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::dendro_plot` plot function.
2. New `?TOmicsVis::gene_rank_plot` plot function.
3. New vignettes documents.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

---

## TOmicsVis 1.1.6

**Date**: 2023-07-03

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed test problems from CRAN team.
2. Update README.rmd and README.md.

---

## TOmicsVis 1.1.5

**Date**: 2023-07-02

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::heatmap_group_data` plot function.
2. New `?TOmicsVis::heatmap_group` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed import and importFrom problems.

---

## TOmicsVis 1.1.4

**Date**: 2023-07-01

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::network_data` plot function.
2. New `?TOmicsVis::network_plot` plot function.
3. New `?TOmicsVis::wgcna_gene_exp` plot function.
4. New `?TOmicsVis::wgcna_sample_group` plot function.
5. New `?TOmicsVis::wgcna_pipeline` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.1.3

**Date**: 2023-06-30

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::kegg_enrich` plot function.
2. New `?TOmicsVis::kegg_enrich_bar` plot function.
3. New `?TOmicsVis::kegg_enrich_dot` plot function.
4. New `?TOmicsVis::kegg_enrich_tree` plot function.
5. New `?TOmicsVis::kegg_enrich_net` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.1.2

**Date**: 2023-06-30

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::go_enrich_bar` plot function.
2. New `?TOmicsVis::go_enrich_dot` plot function.
3. New `?TOmicsVis::go_enrich_tree` plot function.
4. New `?TOmicsVis::go_enrich_net` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.1.1

**Date**: 2023-06-30

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::go_anno` example dataset.
2. New `?TOmicsVis::go_deg_fc` plot function.
3. New `?TOmicsVis::go_enrich` plot function.
4. New `?TOmicsVis::go_enrich_stat` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.1.0

**Date**: 2023-06-28

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::table_cross_data1` example dataset.
2. New `?TOmicsVis::table_cross_data2` plot function.
3. New `?TOmicsVis::table_cross` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.9

**Date**: 2023-06-27

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::table_merge_data` example dataset.
2. New `?TOmicsVis::table_merge` plot function.
3. New `?TOmicsVis::table_filter_data` example dataset.
4. New `?TOmicsVis::table_filter` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.8

**Date**: 2023-06-26

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::survival_data` example dataset.
2. New `?TOmicsVis::survival_plot` plot function.
3. New `?TOmicsVis::tsne_data` example dataset.
4. New `?TOmicsVis::tsne_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.7

**Date**: 2023-06-26

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::trend_data` example dataset.
2. New `?TOmicsVis::trend_plot` plot function.
3. New `?TOmicsVis::table_split_data` example dataset.
4. New `?TOmicsVis::table_split` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `_pkgdown.yml` categories and functions.

---

## TOmicsVis 1.0.6

**Date**: 2023-06-25

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::deg_data` example dataset.
2. New `?TOmicsVis::volcano_plot` plot function.
3. New `?TOmicsVis::deg_data2` example dataset.
4. New `?TOmicsVis::ma_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.5

**Date**: 2023-06-24

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::chord_data` example dataset.
2. New `?TOmicsVis::chord_plot` plot function.
3. New `?TOmicsVis::circos_heatmap_data` example dataset.
4. New `?TOmicsVis::circos_heatmap` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Set function invisible().

---

## TOmicsVis 1.0.4

**Date**: 2023-06-23

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::quantile_data` example dataset.
2. New `?TOmicsVis::quantile_plot` plot function.
3. New `?TOmicsVis::venn_data` example dataset.
4. New `?TOmicsVis::venn_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. None.

---

## TOmicsVis 1.0.3

**Date**: 2023-06-22

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::box_data` example datasets.
2. New `?TOmicsVis::box_plot` plot function.
3. New `?TOmicsVis::violin_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `_pkgdown.yml` theme configure.

---

## TOmicsVis 1.0.2

**Date**: 2023-06-21

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. New `?TOmicsVis::pca_sample_gene` and `?TOmicsVis::pca_group_sample` example datasets.
2. New `?TOmicsVis::pca_plot` plot function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `_pkgdown.yml` configure reference `ggplot2`: [https://github.com/tidyverse/ggplot2/blob/main/README.Rmd](https://github.com/tidyverse/ggplot2/blob/main/README.Rmd).

---

## TOmicsVis 1.0.1

**Date**: 2023-06-20

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. Open source code of TOmicsVis to github: [https://github.com/benben-miao/TOmicsVis/](https://github.com/benben-miao/TOmicsVis/).
2. Build pkgdown website: [https://benben-miao.github.io/TOmicsVis/](https://benben-miao.github.io/TOmicsVis/) for TOmicsVis package.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

1. Fixed `DESCRIPTION` import parameters
2. Fixed `_pkgdown.yml` configure file using Visual Studio Code.

---

## TOmicsVis 1.0.0

**Date**: 2023-06-20

<span style="background-color: green; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">New Features:</span>

1. Create TOmicsVis package and complete the `DESCRIPTION` file.
2. New `?TOmicsVis::gene_exp` example data and `?TOmicsVis::corr_heatmap` function.

<span style="background-color: red; border-radius: 10px; padding: 0px 5px; font-weight: bold; color: white;">Bugs Fixed:</span>

None
